diff --git a/asdf.asd b/asdf.asd
index 0f2c4e94e48f1723578278b8b20be9b6a04b9d0c..326376cfa32c65a216dfa54b2e90267c6420606c 100644
--- a/asdf.asd
+++ b/asdf.asd
@@ -14,7 +14,7 @@
   :licence "MIT"
   :description "Another System Definition Facility"
   :long-description "ASDF builds Common Lisp software organized into defined systems."
-  :version "2.26.32" ;; to be automatically updated by bin/bump-revision
+  :version "2.26.33" ;; to be automatically updated by bin/bump-revision
   :depends-on ()
   :components
   ((:file "asdf")))
diff --git a/asdf.lisp b/asdf.lisp
index b2daa93b41772dd5e9aa337c136666ce18f0d1a1..71ae2aa34a1296f715f56c3740247f3014571986 100644
--- a/asdf.lisp
+++ b/asdf.lisp
@@ -1,5 +1,5 @@
 ;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp ; coding: utf-8 -*-
 ;;; This is ASDF 2.26.32: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
 ;;; please mail to <asdf-devel@common-lisp.net>.
@@ -118,7 +118,7 @@
          ;; "2.345.6" would be a development version in the official upstream
          ;; "2.345.0.7" would be your seventh local modification of official release 2.345
          ;; "2.345.6.7" would be your seventh local modification of development version 2.345.6
-         (asdf-version "2.26.32")
+         (asdf-version "2.26.33")
          (existing-asdf (find-class 'component nil))
          (existing-version *asdf-version*)
          (already-there (equal asdf-version existing-version)))
@@ -2134,7 +2134,11 @@ PREVIOUS-TIME when not null is the time at which the PREVIOUS system was loaded.
     (assert (length=n-p files 1))
     (first files)))
 
-(defmethod input-files ((o operation) (c component))
+(defmethod input-files ((o operation) (c parent-component))
+  (declare (ignorable o c))
+  nil)
+
+(defmethod input-files ((o operation) (c file-component))
   (let ((self-deps (component-self-dependencies o c)))
     (or (and self-deps
              (loop :for dep :in self-deps
@@ -1,5 +1,5 @@
 ;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp ; coding: utf-8 -*-
-;;; This is ASDF 2.26.32: Another System Definition Facility.
+;;; This is ASDF 2.26.33: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome: